function y = funk1(x)
% funk1 - function y=x^2-2
%   
% 
%   Syntax: 
%           y = funk1(x)
%   Arguments: 
%           x - a real number
%   Returns: 
%           y - a real number
%           
%   Description:
%
%           Computes the function y=x^2-2 for computing the square
%           root of 2 by the bisection or newton methods. 
%           
%   See also:
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          991017
%   Author:
%          Stig Larsson
%
%   Change history:
%
%                              +---------------------------------------+ 
%                              |     Matematik Kf/Kb 1999-2000         | 
%                              |     Copyright (c) 1999                | 
%                              |                                       | 
%                              |     Stig Larsson                      | 
%                              |     Mathematics                       | 
%                              |     Chalmers University of Technology | 
%                              |     SE-412 96 Goteborg                | 
%                              |     SWEDEN                            |     
%                              |     stig@math.chalmers.se             |     
%                              |     http://www.math.chalmers.se/~stig |     
%------------------------------+---------------------------------------+
y=x.^2-2;

